@@ -9,6 +9,8 @@ import shutil
 import importlib
 from zipfile import ZipFile
 from pathlib import Path
+import time
+from datetime import datetime, timezone, timedelta
 
 
 ##########
@@ -558,6 +560,29 @@ def write_file(file:str, content:str=''):
         return False
 
 
+##
+# @desc Reads a file and returns its content if exists
+#
+# @param file_path: str - The absolute file path
+#
+# @retun any
+##
+def read_file(file_path:str):
+    # File already exists
+    if os.path.exists(file_path):
+        # Read file
+        with open(file_path, 'r') as file:
+            f = file.read()
+
+        # Return result
+        return f
+
+    # File not exists
+    else:
+        # Return Result
+        return False
+
+
 ##
 # @desc Writes to a file if exists
 #
@@ -1169,8 +1194,6 @@ def column_name(name:str):
         }
 
 
-import time
-from datetime import datetime, timezone, timedelta
 ################
 # Time Helpers #
 ################
@@ -1190,7 +1213,6 @@ def current_time():
 #
 # @retun str
 ##
-# Create datetime from time (milliseconds)
 def current_date(format: str = '%Y-%m-%d %H:%M:%S'):
     return datetime.fromtimestamp(round(current_time() / 1000.0)).strftime(format)
 
@@ -1203,6 +1225,5 @@ def current_date(format: str = '%Y-%m-%d %H:%M:%S'):
 #
 # @retun str
 ##
-# Create datetime from time (milliseconds)
 def generate_date(time_ms: int, format: str = '%Y-%m-%d %H:%M:%S'):
     return datetime.fromtimestamp(round(time_ms / 1000.0)).strftime(format)
